@@ -6,7 +6,7 @@ use Carp;
 
 use Vcdiff;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 require XSLoader;
 XSLoader::load('Vcdiff::Xdelta3', $VERSION);
@@ -24,6 +24,7 @@ sub diff {
     croak "diff needs source argument";
   } elsif (ref $source eq 'GLOB') {
     $source_fileno = fileno($source);
+    croak "source file handle is closed or invalid" if !defined $source_fileno || $source_fileno == -1;
   } else {
     $source_str = $source;
   }
@@ -32,6 +33,7 @@ sub diff {
     croak "diff needs target argument";
   } elsif (ref $input eq 'GLOB') {
     $input_fileno = fileno($input);
+    croak "target file handle is closed or invalid" if !defined $input_fileno || $input_fileno == -1;
   } else {
     $input_str = $input;
   }
@@ -41,6 +43,7 @@ sub diff {
       if ref $output ne 'GLOB';
 
     $output_fileno = fileno($output);
+    croak "output file handle is closed or invalid" if !defined $output_fileno || $output_fileno == -1;
   } else {
     $output_str = '';
   }
@@ -64,6 +67,7 @@ sub patch {
     croak "patch needs source argument";
   } elsif (ref $source eq 'GLOB') {
     $source_fileno = fileno($source);
+    croak "source file handle is closed or invalid" if !defined $source_fileno || $source_fileno == -1;
   } else {
     $source_str = $source;
   }
@@ -72,6 +76,7 @@ sub patch {
     croak "patch needs delta argument";
   } elsif (ref $input eq 'GLOB') {
     $input_fileno = fileno($input);
+    croak "delta file handle is closed or invalid" if !defined $input_fileno || $input_fileno == -1;
   } else {
     $input_str = $input;
   }
@@ -81,6 +86,7 @@ sub patch {
       if ref $output ne 'GLOB';
 
     $output_fileno = fileno($output);
+    croak "output file handle is closed or invalid" if !defined $output_fileno || $output_fileno == -1;
   } else {
     $output_str = '';
   }
